CA10_Cl05.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=Añadir usuario |
type | id_username | nuevousuario
type | id_password1 | 1234
type | id_password2 | 1234
clickAndWait | _addanother |
verifyTextPresent | Se añadió con éxito el user "nuevousuario". |
verifyTextPresent | Añadir usuario |
open | http://beta.merengue.yaco.es/admin/auth/user/ |
clickAndWait | link=nuevousuario |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Añadir usuario |
type | id_username | nuevousuario
type | id_password1 | 1234
type | id_password2 | 1234
clickAndWait | _save |
verifyTextPresent | Se añadió con éxito el user "nuevousuario". Puede editarlo de nuevo abajo. |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Añadir usuario |
type | id_username | nuevousuario
type | id_password1 | 1234
type | id_password2 | 1234
clickAndWait | _continue |
verifyTextPresent | Se añadió con éxito el user "nuevousuario". Puede editarlo de nuevo abajo. |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |